@@ -32,9 +32,6 @@
 #include "newgamesetup.h"
 #include "krightdialog.h"
 #include "Dialogs/joingame.h"
-#if HAVE_JABBER_SUPPORT
-#include "Jabber/kmessagejabber.h"
-#endif
 #include "newplayerdata.h"
 #include "gamesequence.h"
 
@@ -303,7 +300,7 @@ GameAutomaton::GameState GameAutomaton::run()
       qCDebug(KSIRK_LOG) << "opened";
       bool ok;
       m_port = QInputDialog::getInt(m_game,
-              i18n("KsirK - Network configuration"), 
+              i18nc("@title:window", "Network Configuration"),
               i18n("Please type in the port number on which to offer connections:"), 
               m_port, 0, 32000, 1, &ok);
       offerConnections(m_port);
@@ -1191,7 +1188,7 @@ bool GameAutomaton::joinNetworkGame()
 {
   qCDebug(KSIRK_LOG);
    if (stateName() == "INIT"
-     || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KGuiItem(i18nc("@action:button", "Join New Game"))) == KMessageBox::Continue))
+     || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"), i18nc("@title:window", "New Game Confirmation"),KGuiItem(i18nc("@action:button", "Join New Game"))) == KMessageBox::Continue))
    {
       m_game->joinNetworkGame();
    }
@@ -1217,45 +1214,6 @@ bool GameAutomaton::connectToServ()
   return status;
 }
 
-#if HAVE_JABBER_SUPPORT
-bool GameAutomaton::joinJabberGame(const QString& nick)
-{
-  if (stateName() == "INIT" || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KGuiItem(i18nc("@action:button", "Join New Game"))) == KMessageBox::Continue))
-  {
-    // stop game
-    setGameStatus(KGame::End);
-    state(INIT);
-    savedState(INVALID);
-    
-    if (messageServer() != nullptr)
-    {
-      QObject::disconnect(messageServer(),&KMessageServer::connectionLost,
-                           this,&GameAutomaton::slotConnectionToClientBroken);
-    }
-    
-    qCDebug(KSIRK_LOG) << "Before connectToServer";
-    m_game->setServerJid(nick);
-    KMessageJabber* messageIO = new KMessageJabber(m_game->serverJid().full(), m_game->jabberClient(), this);
-    bool status = connectToServer(messageIO);
-    //       bool status = connectToServer(host, port);
-    qCDebug(KSIRK_LOG) << "After connectToServer" << status;
-    if (status)
-    {
-      QByteArray msg("connect");
-      XMPP::Message message(m_game->serverJid().full());
-      message.setType("ksirkgame");
-      message.setId(QUuid::createUuid().toString().remove("{").remove("}").remove("-"));
-      message.setBody(msg);
-      m_game->jabberClient()->sendMessage(message);
-    }
-    //       connect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
-                                                           //          this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
-                                                           return status;
-  }
-  return false;
-}
-#endif
-
 KPlayer * GameAutomaton::createPlayer(int rtti, 
                                     int /*io*/, 
                                     bool isVirtual)    
@@ -1507,7 +1465,7 @@ void GameAutomaton::changePlayerName(Player* player)
   QString nomEntre = player->name();
   
   bool found = true;
-  KMessageBox::information(m_game, i18n("Please choose another name"), i18n("KsirK - Name already used!"));
+  KMessageBox::information(m_game, i18n("Please choose another name."), i18nc("@title:window", "Name Already Used"));
   while(found)
   {
     bool emptyName = true;
@@ -1570,7 +1528,7 @@ void GameAutomaton::changePlayerNation(Player* player)
   QString nationName;
   
   QString nomEntre = player->name();
-  KMessageBox::information(m_game, i18n("Please choose another nation"), i18n("KsirK - Nation already used!"));
+  KMessageBox::information(m_game, i18n("Please choose another nation."), i18nc("@title:window", "Nation Already Used"));
   QString password;
   QByteArray buffer;
   QDataStream stream(&buffer, QIODevice::WriteOnly);
@@ -1663,10 +1621,10 @@ void GameAutomaton::slotConnectionToServerBroken()
   {
     int answer = KMessageBox::questionTwoActionsCancel(m_game,
                                                   i18n("KsirK - Lost connection to server!\nWhat do you want to do?"),
-                                                  i18n("Starting a new game or exit."),
-                                                  KGuiItem(i18n("New Game")),
-                                                  KGuiItem(i18n("Exit")),
-                                                  KGuiItem(i18n("Do nothing")));
+                                                  i18nc("@title:window", "Starting a New Game or Exit."),
+                                                  KGuiItem(i18nc("@action:button", "New Game"), QStringLiteral("document-new")),
+                                                  KGuiItem(i18nc("@action:button", "Exit"), QStringLiteral("application-exit")),
+                                                  KGuiItem(i18nc("@action:button", "Do Nothing")));
     if (answer == KMessageBox::PrimaryAction)
     {
       m_game->showMainMenu();
@@ -1689,7 +1647,7 @@ void GameAutomaton::slotConnectionToClientBroken(KMessageIO *)
   {
     KMessageBox::information(m_game, 
                             i18n("Lost connection to a client.\nFor the moment, you can only save the game and start a new one or quit.\nThis will be improved in a future version."), 
-                            i18n("KsirK - Lost connection to client!"));
+                            i18nc("@title:window", "Lost Connection to Client"));
     switch ( KMessageBox::warningTwoActions( m_game,
                                         i18n("Do want to save your game?"),
                                         QString(),
@@ -1941,7 +1899,7 @@ void GameAutomaton::displayGoals()
           game(),
           i18n("%1, your goal will be displayed. Please<br>"
                "make sure that no other player can see it!",(*it)->name()),
-          i18n("KsirK - Displaying Goal"));
+          i18nc("@title:window", "Displaying Goal"));
       dynamic_cast<Player*>(*it)->goal().show();
     }
   }
@@ -2377,7 +2335,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     {
       if (explosing != 0 && explosing != 1 && explosing != 2)
       {
-        KMessageBox::information(m_game, i18n("Problem : no one destroyed"), i18n("KsirK - Error!"));
+        KMessageBox::error(m_game, i18n("Problem : no one destroyed"));
       }
       else
       {
@@ -2426,7 +2384,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   case InvalidPassword:
     if (receiver == gameId())
     {
-      KMessageBox::information(m_game, i18n("You entered an invalid password.\nPlease try again."), i18n("KsirK - Invalid password!"));
+      KMessageBox::information(m_game, i18n("You entered an invalid password.\nPlease try again."), i18nc("@title:window", "Invalid Password"));
       m_game->setupOneWaitedPlayer();
     }
     break;
@@ -2566,13 +2524,6 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   }
 }
 
-#if HAVE_JABBER_SUPPORT
-void GameAutomaton::askForJabberGames()
-{
-  m_game->askForJabberGames();
-}
-#endif
-
 QSvgRenderer& GameAutomaton::rendererFor(const QString& skinName)
 {
   if (!m_renderers.contains(skinName))
@@ -2635,7 +2586,7 @@ void GameAutomaton::actionNextPlayer()
     || m_currentPlayerPlayed
     || (KMessageBox::questionTwoActions (m_game,
                                     i18n("%1, you have not played anything this turn.\nDo you really want to lose your turn?",m_currentPlayer),
-                                    i18n("Really Next Player?"),
+                                    i18nc("@title:window", "Next Player Confirmation"),
                                     KGuiItem(i18nc("@action:button", "Next Player")),
                                     KStandardGuiItem::cancel())
        == KMessageBox::PrimaryAction) )
